derive_pll_clocks -create_base_clocks

########### Cyclone III NEEK ##########################
set SYSTEM_CLK eth_std_main_system_inst|sdram|eth_std_main_system_sdram_controller_phy_inst|eth_std_main_system_sdram_phy_inst|eth_std_main_system_sdram_phy_alt_mem_phy_inst|clk|pll|altpll_component|auto_generated|pll1|clk[0]

################ Flash ######################
# data/address bus shared via Tristate bridge
set_min_delay 0.0 -from [get_ports {flash_d[*]}] -to *
set_max_delay 8.0 -from [get_ports {flash_d[*]}] -to *

set_min_delay  0.0 -from * -to [get_ports {flash_a[*] flash_d[*] flash_cs_n flash_oe_n flash_we_n}]
set_max_delay  8.0 -from * -to [get_ports {flash_a[*] flash_d[*] flash_cs_n flash_oe_n flash_we_n}]

################ EEPROM ######################
set_min_delay 0.0 -from [get_ports id_eeprom_dat] -to *
set_max_delay 8.0 -from [get_ports id_eeprom_dat] -to *

set_min_delay  0.0 -from * -to [get_ports {id_eeprom_dat id_eeprom_scl}]
set_max_delay  8.0 -from * -to [get_ports {id_eeprom_dat id_eeprom_scl}]

################# Asynchronous ###########################
# Buttons
set_false_path -from [get_ports {button_pio[*]}] -to *
# Reset
set_false_path -from [get_ports {reset_n}] -to *
# LEDS
set_false_path -from * -to [get_ports {led_pio[*]}]

# SOPC Builder Clock Crossing Reset Synchronization
#set_false_path -from [get_keepers *resetn_out] -to [get_keepers {*domain_synch|data_out *domain_synch|data_in_d1}]
#set_false_path -from [get_keepers *oci_debug|resetrequest] -to [get_keepers {*domain_synch|data_out *domain_synch|data_in_d1}]

#################### Ethernet ############################
#Only using 100 Mbps mode, input clocks at 25 MHz
create_clock -name ETH_RX_CLK -period "25MHz" [get_ports enet_rx_clk]
create_clock -name ETH_TX_CLK -period "25MHz" [get_ports enet_tx_clk]

# Ethernet MAC
set_min_delay 0.0 -from [get_ports { enet_rx_col enet_rx_crs enet_rx_d[*] enet_rx_en enet_rx_err}] -to *
set_max_delay 4.0 -from [get_ports { enet_rx_col enet_rx_crs enet_rx_d[*] enet_rx_en enet_rx_err}] -to *
                                   
set_min_delay 4.0 -from * -to [get_ports {enet_tx_d[*] enet_tx_en}]
set_max_delay 12.0 -from * -to [get_ports {enet_tx_d[*] enet_tx_en}]

# MDIO
set_min_delay 0.0 -from [get_ports {enet_mdio}] -to *
set_max_delay 4.0 -from [get_ports {enet_mdio}] -to *

set_min_delay 4.0 -from * -to [get_ports {enet_mdio enet_mdc}]
set_max_delay 12.0 -from * -to [get_ports {enet_mdio enet_mdc}]

set_multicycle_path -setup 5 -from [ get_registers *|altera_tse_top_w_fifo:U_MAC|altera_tse_tx_min_ff:U_TXFF|altera_tse_altsyncram_dpm_fifo:U_RTSM|altsyncram*] -to [ get_registers *]
set_multicycle_path -setup 5 -from [ get_registers *|altera_tse_top_w_fifo:U_MAC|altera_tse_tx_min_ff:U_TXFF|altera_tse_retransmit_cntl:U_RETR|*] -to [ get_registers *]
set_multicycle_path -setup 5 -from [ get_registers *] -to [ get_registers *|altera_tse_top_w_fifo:U_MAC|altera_tse_tx_min_ff:U_TXFF|altera_tse_retransmit_cntl:U_RETR|*]
set_multicycle_path -hold 5 -from [ get_registers *|altera_tse_top_w_fifo:U_MAC|altera_tse_tx_min_ff:U_TXFF|altera_tse_altsyncram_dpm_fifo:U_RTSM|altsyncram*] -to [ get_registers *]
set_multicycle_path -hold 5 -from [ get_registers *|altera_tse_top_w_fifo:U_MAC|altera_tse_tx_min_ff:U_TXFF|altera_tse_retransmit_cntl:U_RETR|*] -to [ get_registers *]
set_multicycle_path -hold 5 -from [ get_registers *] -to [ get_registers *|altera_tse_top_w_fifo:U_MAC|altera_tse_tx_min_ff:U_TXFF|altera_tse_retransmit_cntl:U_RETR|*]
set_max_delay 7 -from [get_registers *|altera_tse_top_w_fifo:U_MAC|altera_tse_tx_min_ff:U_TXFF|dout_reg_sft*] -to [get_registers *|altera_tse_top_w_fifo:U_MAC|altera_tse_top_1geth:U_GETH|altera_tse_mac_tx:U_TX|*]
set_max_delay 7 -from [get_registers *|altera_tse_top_w_fifo:U_MAC|altera_tse_tx_min_ff:U_TXFF|eop_sft*] -to [get_registers *|altera_tse_top_w_fifo:U_MAC|altera_tse_top_1geth:U_GETH|altera_tse_mac_tx:U_TX|*]
set_max_delay 7 -from [get_registers *|altera_tse_top_w_fifo:U_MAC|altera_tse_tx_min_ff:U_TXFF|sop_reg*] -to [get_registers *|altera_tse_top_w_fifo:U_MAC|altera_tse_top_1geth:U_GETH|altera_tse_mac_tx:U_TX|*]
   
set_clock_groups -exclusive -group ${SYSTEM_CLK} -group {ETH_RX_CLK} -group {ETH_TX_CLK}

#################### JTAG ################################
# JTAG Constraints copied directly from TimeQuest Cookbook
#constrain the TCK port
create_clock -name tck -period "10MHz" [get_ports altera_reserved_tck] -add
#cut all paths to and from tck
set_clock_groups -group [get_clocks tck] -exclusive
#constrain the TDI port
set_input_delay -clock tck 20 [get_ports altera_reserved_tdi]
#constrain the TMS port
set_input_delay -clock tck 20 [get_ports altera_reserved_tms]
#constrain the TDO port
set_output_delay -clock tck 20 [get_ports altera_reserved_tdo]



