module top_level
(
  input       clkin_50,
  input       reset_n,
   
  input   [3:0] button_pio,
   
  //connected to LED0 and LED2 (cannot use LED1 or LED3 due to conflict with ddr VREF)
  output  [1:0] led_pio,    
    
  input       enet_rx_clk,
  input       enet_tx_clk,
  input       enet_rx_col,
  input       enet_rx_crs,
  input   [3:0] enet_rx_d,
  input       enet_rx_en,
  input       enet_rx_err,
  output      enet_reset_n, 
  output      enet_mdc,
  inout         enet_mdio,
  output  [3:0] enet_tx_d,
  output      enet_tx_en,

  output  [12:0]  mem_addr,
  output  [1:0] mem_ba,
  output      mem_cas_n,
  output      mem_cke,
  inout       mem_clk,
  inout       mem_clk_n,
  output      mem_cs_n,
  output  [1:0] mem_dm,
  inout   [15:0]  mem_dq,
  inout   [1:0] mem_dqs,
  output      mem_ras_n,
  output      mem_we_n, 
    
  inout       id_eeprom_dat,
  output      id_eeprom_scl,
        
  output  [23:0]  flash_a,
  inout   [15:0]  flash_d,
  output      flash_we_n,
  output      flash_cs_n,
  output      flash_oe_n
);

wire             mdio_in;
wire             mdio_oen;
wire             mdio_out;
  
// MDIO Tristate
//--------------
assign mdio_in = enet_mdio;
assign enet_mdio =  (mdio_oen == 1'b0)? mdio_out : 1'bz;  
 
assign enet_reset_n = reset_n; 

eth_std_main_system eth_std_main_system_inst (
  .clk_clk_in_reset_reset_n                     (reset_n),                     //                      clk_clk_in_reset.reset_n
  .clk_in_clk                                   (clkin_50),                                   //                                clk_in.clk
  
  .sdram_memory_mem_clk                            (mem_clk),                            //                          sdram_memory.mem_ck
  .sdram_memory_mem_ba                            (mem_ba),                            //                                      .mem_ba
  .sdram_memory_mem_addr                             (mem_addr),                             //                                      .mem_a
  .sdram_memory_mem_dqs                           (mem_dqs),                           //                                      .mem_dqs
  .sdram_memory_mem_cas_n                         (mem_cas_n),                         //                                      .mem_cas_n
  .sdram_memory_mem_clk_n                          (mem_clk_n),                          //                                      .mem_ck_n
  .sdram_memory_mem_dm                            (mem_dm),                            //                                      .mem_dm
  .sdram_memory_mem_dq                            (mem_dq),                            //                                      .mem_dq
  .sdram_memory_mem_cke                           (mem_cke),                           //                                      .mem_cke
  .sdram_memory_mem_cs_n                          (mem_cs_n),                          //                                      .mem_cs_n
  .sdram_memory_mem_we_n                          (mem_we_n),                          //                                      .mem_we_n
  .sdram_memory_mem_ras_n                         (mem_ras_n),      
      
  .flash_tristate_bridge_out_tcm_chipselect_n_out (flash_cs_n), //             flash_tristate_bridge_out.tcm_chipselect_n_out
  .flash_tristate_bridge_out_tcm_address_out      (flash_a),      //                                      .tcm_address_out
  .flash_tristate_bridge_out_tcm_data_out         (flash_d),         //                                      .tcm_data_out
  .flash_tristate_bridge_out_tcm_read_n_out       (flash_oe_n),       //                                      .tcm_read_n_out
  .flash_tristate_bridge_out_tcm_write_n_out      (flash_we_n),   
  
  .pio_id_eeprom_dat_external_connection_export (id_eeprom_dat), // pio_id_eeprom_dat_external_connection.export
  .led_pio_external_connection_export           (led_pio),           //           led_pio_external_connection.export
  .button_pio_external_connection_export        (button_pio),        //        button_pio_external_connection.export
  .pio_id_eeprom_scl_external_connection_export (id_eeprom_scl), // pio_id_eeprom_scl_external_connection.export
  .tse_conduit_connection_set_10                (1'b0),                //                tse_conduit_connection.set_10
  .tse_conduit_connection_m_rx_col              (enet_rx_col),              //                                      .m_rx_col
  .tse_conduit_connection_m_tx_d                (enet_tx_d),                //                                      .m_tx_d
  .tse_conduit_connection_gm_tx_err             (),             //                                      .gm_tx_err
  .tse_conduit_connection_gm_rx_d               (1'b0),               //                                      .gm_rx_d
  .tse_conduit_connection_m_rx_d                (enet_rx_d),                //                                      .m_rx_d
  .tse_conduit_connection_m_rx_en               (enet_rx_en),               //                                      .m_rx_en
  .tse_conduit_connection_m_rx_err              (enet_rx_err),              //                                      .m_rx_err
  .tse_conduit_connection_m_rx_crs              (enet_rx_crs),              //                                      .m_rx_crs
  .tse_conduit_connection_tx_clk                (enet_tx_clk),                //                                      .tx_clk
  .tse_conduit_connection_mdio_out              (mdio_out),              //                                      .mdio_out
  .tse_conduit_connection_gm_tx_en              (),              //                                      .gm_tx_en
  .tse_conduit_connection_mdc                   (enet_mdc),                   //                                      .mdc
  .tse_conduit_connection_m_tx_err              (),              //                                      .m_tx_err
  .tse_conduit_connection_set_1000              (1'b0),              //                                      .set_1000
  .tse_conduit_connection_gm_tx_d               (),               //                                      .gm_tx_d
  .tse_conduit_connection_gm_rx_dv              (1'b0),              //                                      .gm_rx_dv
  .tse_conduit_connection_gm_rx_err             (1'b0),             //                                      .gm_rx_err
  .tse_conduit_connection_ena_10                (),                //                                      .ena_10
  .tse_conduit_connection_eth_mode              (),              //                                      .eth_mode
  .tse_conduit_connection_mdio_oen              (mdio_oen),              //                                      .mdio_oen
  .tse_conduit_connection_rx_clk                (enet_rx_clk),                //                                      .rx_clk
  .tse_conduit_connection_m_tx_en               (enet_tx_en),               //                                      .m_tx_en
  .tse_conduit_connection_mdio_in               (mdio_in)                //                                      .mdio_in
  );  
  
endmodule
